import React from "react";
import CartItem from "./CartItem";
import useLanguage from "../../hooks/useLanguage";

function ProductDivision({ shops }) {
  const language = useLanguage();
  return (
    <div className=" w-full bg-white xl:p-7  p-4 rounded-md shadow-custom mt-4 xl:mt-0 ">
      <table className="w-full">
        <thead className="w-full ">
          <tr className=" bg-primary-200 bg-opacity-5 rounded-t-sm border-b border-b-primary-200 w-full  xl:gap-9 gap-3 grid  grid-cols-12 px-5 py-4 justify-start items-center">
            <th className="flex h-fit items-center gap-3 col-span-12  xl:col-span-7">
              <img
                src={process.env.BASE_URL + shops.logo}
                alt="logo"
                className=" max-w-14 "
              />
              <h1 className=" lg:text-2xl  lg:font-bold text-dark-300 notranslate">
                {shops?.shop_name}
              </h1>
            </th>
            <th className="col-span-2 w-full  text-left hidden xl:block">
              <p className="  text-base text-dark-300 font-normal notranslate">
                {language["Weight"]}
              </p>
            </th>
            <th className=" col-span-2 text-left hidden xl:block">
              <p className=" text-base text-dark-300 font-normal notranslate">
                {language["Price"]}
              </p>
            </th>
            <th className=" col-span-1 hidden xl:block">
              <svg
                xmlns="http://www.w3.org/2000/svg"
                width="26"
                height="26"
                viewBox="0 0 26 26"
                fill="none"
              >
                <path
                  d="M16.064 16.064L9.93571 9.93571M9.9357 16.064L16.064 9.93571M12.9998 23.8332C18.9829 23.8332 23.8332 18.9829 23.8332 12.9998C23.8332 7.01675 18.9829 2.1665 12.9998 2.1665C7.01675 2.1665 2.1665 7.01675 2.1665 12.9998C2.1665 18.9829 7.01675 23.8332 12.9998 23.8332Z"
                  stroke="#EB5757"
                  strokeWidth="1.5"
                  strokeLinecap="round"
                />
              </svg>
            </th>
          </tr>
        </thead>
        <tbody>
          {shops?.products?.map((product) => (
            <CartItem key={product.id} product={product} />
          ))}
        </tbody>
        <tfoot className=" border-t  border-primary-200">
          <tr className="gap-9 grid  xl:grid-cols-12 grid-cols-4 px-5 py-4 justify-start items-center">
            <td className=" xl:col-span-7 hidden xl:block"></td>
            <td className="col-span-2 ">
              <p className=" text-base font-normal text-dark-200 notranslate">
                {language["Total Weight"]}
              </p>
              <p className=" lg:text-xl text-lg font-bold text-dark-300 notranslate">
                {shops?.products.reduce(
                  (total, qty) => Number(total) + Number(qty.qty),
                  0
                )}{" "}
                {language["Ton"]}
              </p>
            </td>
            <td className="xl:col-span-3 col-span-2">
              <p className=" text-base font-normal text-dark-200 flex notranslate">
                {language["Total Price"]}
                {/* <span className="lg:block hidden"> + vat</span> */}
              </p>
              <p className=" lg:text-xl text-lg font-bold text-dark-300">
                $
                {shops?.products.reduce(
                  (total, product) =>
                    (
                      Number(total) +
                      Number(product.qty) *
                        Number(
                          product?.warehouse_product?.price
                            ? product?.warehouse_product?.price
                            : product.product.price
                        )
                    ).toFixed(2),
                  0
                )}
              </p>
            </td>
          </tr>
        </tfoot>
      </table>
    </div>
  );
}

export default ProductDivision;
